DenseUVPolynomial

Trait DenseUVPolynomial 

pub trait DenseUVPolynomial<F: Field>: Polynomial<F, Point = F> {
    // Required methods
    fn from_coefficients_slice(coeffs: &[F]) -> Self;
    fn from_coefficients_vec(coeffs: Vec<F>) -> Self;
    fn coeffs(&self) -> &[F];
    fn rand<R: Rng>(d: usize, rng: &mut R) -> Self;
}
Describes the interface for univariate polynomials

Required Methods

fn from_coefficients_slice(coeffs: &[F]) -> Self

Constructs a new polynomial from a list of coefficients.

fn from_coefficients_vec(coeffs: Vec<F>) -> Self

Constructs a new polynomial from a list of coefficients.

fn coeffs(&self) -> &[F]

Returns the coefficients of self

fn rand<R: Rng>(d: usize, rng: &mut R) -> Self

Returns a univariate polynomial of degree d where each coefficient is sampled uniformly at random.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors